%define major	2
%define libname	%mklibname %{name} %{major}
%define devname	%mklibname %{name} -d
%define uname	bladeRF

#define rcver	rc3

Name:		bladerf
Version:	2024.05
Release:	%mkrel %{?rcver:0.%{rcver}.}1
Summary:	A Software Defined Radio (SDR) platform
Group:		Communications/Radio
License:	GPLv2
URL:		https://nuand.com/
# Don't use upstream tarball as it does not contain git submodules
# Clone git, checkout tag and then 'git submodule init'; 'git submodule update' and re-create tarball OR...
# Modify mk-tar for the tag required and run ./mk-tar in SOURCES to create tarball with git submodules.
Source0:	https://github.com/Nuand/%{uname}/archive/%{version}%{?rcver:-%{rcver}}/%{uname}-%{version}%{?rcver:-%{rcver}}.tar.bz2
Source1:    mk-tar

Patch0:		bladerf-2024.05_calloc_order.patch

BuildRequires:	cmake
BuildRequires:	pkgconfig(libusb-1.0)
BuildRequires:	doxygen

%description
%{uname} is a Software Defined Radio (SDR) platform designed to enable a
community of hobbyists, and professionals to explore and experiment with the
multidisciplinary facets of RF communication.

%package -n %{libname}
Summary:	Library files for %{uname}
Group:		System/Libraries
Requires:	%{name} = %{version}-%{release}

%package -n %{devname}
Summary:	Development files for %{uname}
Group:		System/Libraries
Requires:	%{libname} = %{version}-%{release}
Requires:	%{name} = %{version}-%{release}
Provides:	%{name}-devel = %{version}-%{release}
Provides:	%{uname}-devel = %{version}-%{release}

%description -n %{devname}
Files needed to develop software against libbladerf.

%description -n %{libname}
bladerf library files.

%package doc
Summary:	HTML documentation for %{uname}
Group:		Documentation
BuildArch:	noarch

%description doc
HTML documentation for %{uname}

%prep
%setup -q -n %{uname}-%{version}%{?rcver:-%{rcver}}
%autopatch -p1

%build

mkdir build
cd build
cmake ../host \
    -DCMAKE_INSTALL_PREFIX=%{_usr} \
    -DCMAKE_BUILD_TYPE:STRING=Debug \
    -DBUILD_DOCUMENTATION=ON

%make_build

%install
%make_install -C build

mkdir -p %{buildroot}%{_udevrulesdir}
mv %{buildroot}%{_sysconfdir}/udev/rules.d/88-nuand*.rules %{buildroot}%{_udevrulesdir}/

mkdir -p %{buildroot}%{_iconsdir}
cp %{buildroot}%{_docdir}/libbladeRF/html/logo.png %{buildroot}%{_iconsdir}/%{name}.png

cat > %{name}-doc.desktop << EOF
[Desktop Entry]
Version=1.0
Name=BladeRF Documentation
GenericName=BladeRF Documentation
Exec=xdg-open %{_docdir}/libbladeRF/html/index.html
Icon=%{name}
Terminal=false
Type=Application
Categories=System;Documentation;X-Mageia-CrossDesktop;
X-Desktop-File-Install-Version=0.19
EOF

# Fix Version string in .pc
sed -i '/Version/c Version: %{version}' %{buildroot}%{_libdir}/pkgconfig/lib%{uname}.pc

desktop-file-install \
--dir=%{buildroot}%{_datadir}/applications %{name}-doc.desktop

%files
%doc CONTRIBUTORS README.md
%{_udevrulesdir}/88-nuand*.rules
%{_bindir}/%{uname}-cli
%{_bindir}/%{uname}-fsk

%files -n %{libname}
%{_libdir}/lib%{uname}.so.%{major}{,.*}

%files -n %{devname}
%{_includedir}/lib%{uname}.h
%{_libdir}/pkgconfig/lib%{uname}.pc
%{_libdir}/lib%{uname}.so
%{_includedir}/bladeRF1.h
%{_includedir}/bladeRF2.h
%{_datadir}/cmake/bladeRF/*

%files doc
%{_docdir}/libbladeRF/html/
%{_datadir}/applications/%{name}-doc.desktop
%{_iconsdir}/%{name}.png
%{_mandir}/man1/bladeRF-cli.1.*


%changelog
* Thu Jun 27 2024 barjac <barjac> 2024.05-1.mga10
+ Revision: 2077451
-new version 2024.05
- patch with fix for calloc parameter order from upstream PR#965

* Mon Feb 20 2023 barjac <barjac> 2023.02-1.mga9
+ Revision: 1944345
- new version 2023.02
- shrink tarball by excluding vcs in mk-tar

* Tue Dec 06 2022 barjac <barjac> 2022.11-2.mga9
+ Revision: 1918381
- new version 2022.11

* Fri Mar 25 2022 umeabot <umeabot> 2021.10-2.mga9
+ Revision: 1825559
- Mageia 9 Mass Rebuild

* Thu Oct 07 2021 barjac <barjac> 2021.10-1.mga9
+ Revision: 1750000
- new version 2021.10

* Fri Mar 26 2021 barjac <barjac> 2021.03-1.mga9
+ Revision: 1710290
- new version 2021.03
- build docs from source tarball
- remove old patches fixed upstream
- add man files
- update files lists

* Thu Aug 20 2020 barjac <barjac> 2019.07-3.mga8
+ Revision: 1617016
- patched to fix build

* Sun Feb 16 2020 umeabot <umeabot> 2019.07-2.mga8
+ Revision: 1536705
- Mageia 8 Mass Rebuild

* Thu Oct 24 2019 barjac <barjac> 2019.07-1.mga8
+ Revision: 1455432
- new version 2019.07
- added mk-tar script to create tarball with git submodules

* Thu Jan 10 2019 barjac <barjac> 2018.12-0.rc3.1.mga7
+ Revision: 1354026
- new version 2018.12-rc3
- new major 2
- included git submodules in tarball
- added more udev rules
- removed obsolete patch
- updated files list

* Wed Oct 03 2018 pterjan <pterjan> 2017.12-0.rc1.2.mga7
+ Revision: 1316088
- Mageia 7 Mass Rebuild

* Thu Dec 14 2017 barjac <barjac> 2017.12-0.rc1.1.mga7
+ Revision: 1182650
- new version 2017.12-rc1
- updated doc version
- added -DCMAKE_BUILD_TYPE:STRING=Debug to fix empty debuginfos
- fix path to icon
- fix version string in .pc file that breaks build
- use %%make_install macro

* Mon Sep 05 2016 barjac <barjac> 2016.06-1.mga6
+ Revision: 1050045
- new full version 2016-06
- re-diff makefile patch

* Fri Jul 15 2016 barjac <barjac> 2016.01-0.rc1.2.mga6
+ Revision: 1042173
- fix for Mga#18949 (bladerf systemd-udevd : specified group plugdev unknown

* Mon Jan 11 2016 barjac <barjac> 2016.01-0.rc1.1.mga6
+ Revision: 921526
- new version 2016.01-rc1

* Wed Aug 26 2015 barjac <barjac> 2015.07-1.mga6
+ Revision: 870064
- new version 2015.07

* Fri Jan 16 2015 barjac <barjac> 2014.11-1.mga5
+ Revision: 810965
- Import package bladerf

